@@ -34,7 +34,6 @@ gradLogL.pss1<- function(parameters, X,data, trace)
   cumti.repl <- cumsum(ti.repl)
   n.cases <- length(ti.repl)
   y <- data[[2]]
-  counts <- data[[3]]
   gr <- rep(as.double(0), nparam)
   k1 <- 1
   
@@ -42,7 +41,7 @@ gradLogL.pss1<- function(parameters, X,data, trace)
   {
     k2<-cumti.repl[i]
     u<-gradient (param=parameters,X=X[k1:k2,], y=y[k1:k2])
-    gr<-gr+counts[i] * u
+    gr<-gr+u
     k1<-k2+1
   }
   
