@@ -5,7 +5,7 @@
 
       DOUBLE PRECISION logL,li,ls
       INTEGER n,npar,y2,key,limit,neval,ier,iord,last,
-     *m,mpar,y1,k,k1,k2,link,link1,maxy,maxy1
+     *m,mpar,y1,k,k2,link,link1,maxy,maxy1
 
       DIMENSION x1(4000,10),theta1(4000),
      *work1(4000),y1(4000),beta1(10),bt1(10),
