@@ -6,7 +6,7 @@
      *beta1(10),bt1(10),fact(0:130)
 
       double precision logL
-      integer y1,i0,i1,np,n,n0,k,m,mpar,link1,maxy1
+      integer y1,i0,i1,np,n,n0,m,mpar,link1,maxy1
 
       COMMON/param/x1,theta1,work1,y1,
      *beta1,bt1,m,mpar,omega1,link1,maxy1
@@ -18,33 +18,34 @@
       call fac(fact,130)
       i0=0
       do 10 i=1,n
-        if (link1.eq.0) then 
-	theta1(i)=work1(i)
-        else if (link1.eq.1) then 
-	theta1(i)=dexp(work1(i))
-       end if
+      if (link1.eq.0) then 
+      theta1(i)=work1(i)
+      else if (link1.eq.1) then 
+      theta1(i)=dexp(work1(i))
+      end if
    10 continue
       i0=1
-   20   if (y1(i0).eq.(-1)) then
+   20 if (y1(i0).eq.(-1)) then
       i0=i0+1
       go to 20
-      end if	
+      end if
 
       n0 = n
-   30   if (y1(n0).eq.(-1)) then
+   30 if (y1(n0).eq.(-1)) then
       n0=n0-1
       go to 30
       end if
 
       logL=0
 
-      logL=-theta1(i0)+y1(i0)*dlog(theta1(i0))
-
+      logL=-theta1(i0)+y1(i0)*dlog(theta1(i0))-dlog(fact(y1(i0)))
+C     logL=-theta1(i0)+y1(i0)*dlog(theta1(i0))
+      
       if (i0.eq.n0) return
       i = i0+1
    40 if (i.le.n0) then
       i1 = i
-   50   if (y1(i1).eq.(-1)) then
+   50 if (y1(i1).eq.(-1)) then
       i1=i1+1
       go to 50
       end if
@@ -52,7 +53,8 @@
 C  i0 is the most recent (past) observation time
 C  i1 is the next observation time
 
-      prob=-theta1(i1)+y1(i1)*dlog(theta1(i1))
+      prob=-theta1(i1)+y1(i1)*dlog(theta1(i1))-dlog(fact(y1(i1)))
+C      prob=-theta1(i1)+y1(i1)*dlog(theta1(i1))
       logL=logL+prob
 
       ! logL = logL+ dlog(prob*fact(y(i1))) 
